pub enum UnifiedExecFeatureMode {
Disabled,
Direct,
ZshFork,
}Variants
Disabled
Unified exec should not be selected by this feature set.
This includes standalone shell_zsh_fork: until
unified_exec_zsh_fork is enabled too, shell_zsh_fork keeps using
the shell command backend instead of silently opting unified exec into
zsh-fork interception.
Direct
ZshFork